[−][src]Trait pyo3::conversion::IntoPy
Similar to std::convert::Into, just that it requires a gil token.
IntoPy<PyObject> (aka IntoPy<Py<PyAny>>) should be implemented to define a conversion from
Rust to Python which can be used by most of PyO3's methods.
Required methods
Loading content...Implementations on Foreign Types
impl<T> IntoPy<Py<PyAny>> for Option<T> where
T: IntoPy<PyObject>, [src]
T: IntoPy<PyObject>,
impl IntoPy<Py<PyAny>> for ()[src]
impl<T, '_> IntoPy<Py<PyAny>> for &'_ T where
T: AsPyPointer, [src]
T: AsPyPointer,
impl IntoPy<Py<PyTuple>> for ()[src]
Converts () to an empty Python tuple.
impl IntoPy<Py<PyAny>> for bool[src]
impl<'a> IntoPy<Py<PyAny>> for &'a [u8][src]
impl<K, V, H> IntoPy<Py<PyAny>> for HashMap<K, V, H> where
K: Hash + Eq + IntoPy<PyObject>,
V: IntoPy<PyObject>,
H: BuildHasher, [src]
K: Hash + Eq + IntoPy<PyObject>,
V: IntoPy<PyObject>,
H: BuildHasher,
impl<K, V> IntoPy<Py<PyAny>> for BTreeMap<K, V> where
K: Eq + IntoPy<PyObject>,
V: IntoPy<PyObject>, [src]
K: Eq + IntoPy<PyObject>,
V: IntoPy<PyObject>,
impl IntoPy<Py<PyAny>> for f64[src]
impl IntoPy<Py<PyAny>> for f32[src]
impl<T> IntoPy<Py<PyAny>> for [T; 0] where
T: ToPyObject, [src]
T: ToPyObject,
impl<T> IntoPy<Py<PyAny>> for [T; 1] where
T: ToPyObject, [src]
T: ToPyObject,
impl<T> IntoPy<Py<PyAny>> for [T; 2] where
T: ToPyObject, [src]
T: ToPyObject,
impl<T> IntoPy<Py<PyAny>> for [T; 3] where
T: ToPyObject, [src]
T: ToPyObject,
impl<T> IntoPy<Py<PyAny>> for [T; 4] where
T: ToPyObject, [src]
T: ToPyObject,
impl<T> IntoPy<Py<PyAny>> for [T; 5] where
T: ToPyObject, [src]
T: ToPyObject,
impl<T> IntoPy<Py<PyAny>> for [T; 6] where
T: ToPyObject, [src]
T: ToPyObject,
impl<T> IntoPy<Py<PyAny>> for [T; 7] where
T: ToPyObject, [src]
T: ToPyObject,
impl<T> IntoPy<Py<PyAny>> for [T; 8] where
T: ToPyObject, [src]
T: ToPyObject,
impl<T> IntoPy<Py<PyAny>> for [T; 9] where
T: ToPyObject, [src]
T: ToPyObject,
impl<T> IntoPy<Py<PyAny>> for [T; 10] where
T: ToPyObject, [src]
T: ToPyObject,
impl<T> IntoPy<Py<PyAny>> for [T; 11] where
T: ToPyObject, [src]
T: ToPyObject,
impl<T> IntoPy<Py<PyAny>> for [T; 12] where
T: ToPyObject, [src]
T: ToPyObject,
impl<T> IntoPy<Py<PyAny>> for [T; 13] where
T: ToPyObject, [src]
T: ToPyObject,
impl<T> IntoPy<Py<PyAny>> for [T; 14] where
T: ToPyObject, [src]
T: ToPyObject,
impl<T> IntoPy<Py<PyAny>> for [T; 15] where
T: ToPyObject, [src]
T: ToPyObject,
impl<T> IntoPy<Py<PyAny>> for [T; 16] where
T: ToPyObject, [src]
T: ToPyObject,
impl<T> IntoPy<Py<PyAny>> for [T; 17] where
T: ToPyObject, [src]
T: ToPyObject,
impl<T> IntoPy<Py<PyAny>> for [T; 18] where
T: ToPyObject, [src]
T: ToPyObject,
impl<T> IntoPy<Py<PyAny>> for [T; 19] where
T: ToPyObject, [src]
T: ToPyObject,
impl<T> IntoPy<Py<PyAny>> for [T; 20] where
T: ToPyObject, [src]
T: ToPyObject,
impl<T> IntoPy<Py<PyAny>> for [T; 21] where
T: ToPyObject, [src]
T: ToPyObject,
impl<T> IntoPy<Py<PyAny>> for [T; 22] where
T: ToPyObject, [src]
T: ToPyObject,
impl<T> IntoPy<Py<PyAny>> for [T; 23] where
T: ToPyObject, [src]
T: ToPyObject,
impl<T> IntoPy<Py<PyAny>> for [T; 24] where
T: ToPyObject, [src]
T: ToPyObject,
impl<T> IntoPy<Py<PyAny>> for [T; 25] where
T: ToPyObject, [src]
T: ToPyObject,
impl<T> IntoPy<Py<PyAny>> for [T; 26] where
T: ToPyObject, [src]
T: ToPyObject,
impl<T> IntoPy<Py<PyAny>> for [T; 27] where
T: ToPyObject, [src]
T: ToPyObject,
impl<T> IntoPy<Py<PyAny>> for [T; 28] where
T: ToPyObject, [src]
T: ToPyObject,
impl<T> IntoPy<Py<PyAny>> for [T; 29] where
T: ToPyObject, [src]
T: ToPyObject,
impl<T> IntoPy<Py<PyAny>> for [T; 30] where
T: ToPyObject, [src]
T: ToPyObject,
impl<T> IntoPy<Py<PyAny>> for [T; 31] where
T: ToPyObject, [src]
T: ToPyObject,
impl<T> IntoPy<Py<PyAny>> for [T; 32] where
T: ToPyObject, [src]
T: ToPyObject,
impl<T> IntoPy<Py<PyAny>> for Vec<T> where
T: IntoPy<PyObject>, [src]
T: IntoPy<PyObject>,
impl IntoPy<Py<PyAny>> for i8[src]
impl IntoPy<Py<PyAny>> for u8[src]
impl IntoPy<Py<PyAny>> for i16[src]
impl IntoPy<Py<PyAny>> for u16[src]
impl IntoPy<Py<PyAny>> for i32[src]
impl IntoPy<Py<PyAny>> for u32[src]
impl IntoPy<Py<PyAny>> for i64[src]
impl IntoPy<Py<PyAny>> for isize[src]
impl IntoPy<Py<PyAny>> for usize[src]
impl IntoPy<Py<PyAny>> for u64[src]
impl IntoPy<Py<PyAny>> for i128[src]
impl IntoPy<Py<PyAny>> for u128[src]
impl<K, S> IntoPy<Py<PyAny>> for HashSet<K, S> where
K: IntoPy<PyObject> + Eq + Hash,
S: BuildHasher + Default, [src]
K: IntoPy<PyObject> + Eq + Hash,
S: BuildHasher + Default,
impl<K> IntoPy<Py<PyAny>> for BTreeSet<K> where
K: IntoPy<PyObject> + Ord, [src]
K: IntoPy<PyObject> + Ord,
impl<'a> IntoPy<Py<PyAny>> for &'a str[src]
impl IntoPy<Py<PyAny>> for String[src]
impl<'a> IntoPy<Py<PyAny>> for &'a String[src]
impl<A: IntoPy<PyObject>> IntoPy<Py<PyAny>> for (A,)[src]
impl<A: IntoPy<PyObject>> IntoPy<Py<PyTuple>> for (A,)[src]
impl<A: IntoPy<PyObject>, B: IntoPy<PyObject>> IntoPy<Py<PyAny>> for (A, B)[src]
impl<A: IntoPy<PyObject>, B: IntoPy<PyObject>> IntoPy<Py<PyTuple>> for (A, B)[src]
impl<A: IntoPy<PyObject>, B: IntoPy<PyObject>, C: IntoPy<PyObject>> IntoPy<Py<PyAny>> for (A, B, C)[src]
impl<A: IntoPy<PyObject>, B: IntoPy<PyObject>, C: IntoPy<PyObject>> IntoPy<Py<PyTuple>> for (A, B, C)[src]
impl<A: IntoPy<PyObject>, B: IntoPy<PyObject>, C: IntoPy<PyObject>, D: IntoPy<PyObject>> IntoPy<Py<PyAny>> for (A, B, C, D)[src]
impl<A: IntoPy<PyObject>, B: IntoPy<PyObject>, C: IntoPy<PyObject>, D: IntoPy<PyObject>> IntoPy<Py<PyTuple>> for (A, B, C, D)[src]
impl<A: IntoPy<PyObject>, B: IntoPy<PyObject>, C: IntoPy<PyObject>, D: IntoPy<PyObject>, E: IntoPy<PyObject>> IntoPy<Py<PyAny>> for (A, B, C, D, E)[src]
impl<A: IntoPy<PyObject>, B: IntoPy<PyObject>, C: IntoPy<PyObject>, D: IntoPy<PyObject>, E: IntoPy<PyObject>> IntoPy<Py<PyTuple>> for (A, B, C, D, E)[src]
impl<A: IntoPy<PyObject>, B: IntoPy<PyObject>, C: IntoPy<PyObject>, D: IntoPy<PyObject>, E: IntoPy<PyObject>, F: IntoPy<PyObject>> IntoPy<Py<PyAny>> for (A, B, C, D, E, F)[src]
impl<A: IntoPy<PyObject>, B: IntoPy<PyObject>, C: IntoPy<PyObject>, D: IntoPy<PyObject>, E: IntoPy<PyObject>, F: IntoPy<PyObject>> IntoPy<Py<PyTuple>> for (A, B, C, D, E, F)[src]
impl<A: IntoPy<PyObject>, B: IntoPy<PyObject>, C: IntoPy<PyObject>, D: IntoPy<PyObject>, E: IntoPy<PyObject>, F: IntoPy<PyObject>, G: IntoPy<PyObject>> IntoPy<Py<PyAny>> for (A, B, C, D, E, F, G)[src]
impl<A: IntoPy<PyObject>, B: IntoPy<PyObject>, C: IntoPy<PyObject>, D: IntoPy<PyObject>, E: IntoPy<PyObject>, F: IntoPy<PyObject>, G: IntoPy<PyObject>> IntoPy<Py<PyTuple>> for (A, B, C, D, E, F, G)[src]
impl<A: IntoPy<PyObject>, B: IntoPy<PyObject>, C: IntoPy<PyObject>, D: IntoPy<PyObject>, E: IntoPy<PyObject>, F: IntoPy<PyObject>, G: IntoPy<PyObject>, H: IntoPy<PyObject>> IntoPy<Py<PyAny>> for (A, B, C, D, E, F, G, H)[src]
impl<A: IntoPy<PyObject>, B: IntoPy<PyObject>, C: IntoPy<PyObject>, D: IntoPy<PyObject>, E: IntoPy<PyObject>, F: IntoPy<PyObject>, G: IntoPy<PyObject>, H: IntoPy<PyObject>> IntoPy<Py<PyTuple>> for (A, B, C, D, E, F, G, H)[src]
impl<A: IntoPy<PyObject>, B: IntoPy<PyObject>, C: IntoPy<PyObject>, D: IntoPy<PyObject>, E: IntoPy<PyObject>, F: IntoPy<PyObject>, G: IntoPy<PyObject>, H: IntoPy<PyObject>, I: IntoPy<PyObject>> IntoPy<Py<PyAny>> for (A, B, C, D, E, F, G, H, I)[src]
impl<A: IntoPy<PyObject>, B: IntoPy<PyObject>, C: IntoPy<PyObject>, D: IntoPy<PyObject>, E: IntoPy<PyObject>, F: IntoPy<PyObject>, G: IntoPy<PyObject>, H: IntoPy<PyObject>, I: IntoPy<PyObject>> IntoPy<Py<PyTuple>> for (A, B, C, D, E, F, G, H, I)[src]
Loading content...Implementors
impl IntoPy<Py<PyAny>> for PyErr[src]
impl<'_> IntoPy<Py<CancelledError>> for &'_ CancelledError[src]
fn into_py(self, py: Python<'_>) -> Py<CancelledError>[src]
impl<'_> IntoPy<Py<IncompleteReadError>> for &'_ IncompleteReadError[src]
fn into_py(self, py: Python<'_>) -> Py<IncompleteReadError>[src]
impl<'_> IntoPy<Py<InvalidStateError>> for &'_ InvalidStateError[src]
fn into_py(self, py: Python<'_>) -> Py<InvalidStateError>[src]
impl<'_> IntoPy<Py<LimitOverrunError>> for &'_ LimitOverrunError[src]
fn into_py(self, py: Python<'_>) -> Py<LimitOverrunError>[src]
impl<'_> IntoPy<Py<QueueEmpty>> for &'_ QueueEmpty[src]
fn into_py(self, py: Python<'_>) -> Py<QueueEmpty>[src]
impl<'_> IntoPy<Py<QueueFull>> for &'_ QueueFull[src]
impl<'_> IntoPy<Py<TimeoutError>> for &'_ TimeoutError[src]
fn into_py(self, py: Python<'_>) -> Py<TimeoutError>[src]
impl<'_> IntoPy<Py<gaierror>> for &'_ gaierror[src]
impl<'_> IntoPy<Py<herror>> for &'_ herror[src]
impl<'_> IntoPy<Py<timeout>> for &'_ timeout[src]
impl<'_> IntoPy<Py<PyArithmeticError>> for &'_ PyArithmeticError[src]
fn into_py(self, py: Python<'_>) -> Py<PyArithmeticError>[src]
impl<'_> IntoPy<Py<PyAssertionError>> for &'_ PyAssertionError[src]
fn into_py(self, py: Python<'_>) -> Py<PyAssertionError>[src]
impl<'_> IntoPy<Py<PyAttributeError>> for &'_ PyAttributeError[src]
fn into_py(self, py: Python<'_>) -> Py<PyAttributeError>[src]
impl<'_> IntoPy<Py<PyBaseException>> for &'_ PyBaseException[src]
fn into_py(self, py: Python<'_>) -> Py<PyBaseException>[src]
impl<'_> IntoPy<Py<PyBlockingIOError>> for &'_ PyBlockingIOError[src]
fn into_py(self, py: Python<'_>) -> Py<PyBlockingIOError>[src]
impl<'_> IntoPy<Py<PyBrokenPipeError>> for &'_ PyBrokenPipeError[src]
fn into_py(self, py: Python<'_>) -> Py<PyBrokenPipeError>[src]
impl<'_> IntoPy<Py<PyBufferError>> for &'_ PyBufferError[src]
fn into_py(self, py: Python<'_>) -> Py<PyBufferError>[src]
impl<'_> IntoPy<Py<PyChildProcessError>> for &'_ PyChildProcessError[src]
fn into_py(self, py: Python<'_>) -> Py<PyChildProcessError>[src]
impl<'_> IntoPy<Py<PyConnectionAbortedError>> for &'_ PyConnectionAbortedError[src]
fn into_py(self, py: Python<'_>) -> Py<PyConnectionAbortedError>[src]
impl<'_> IntoPy<Py<PyConnectionError>> for &'_ PyConnectionError[src]
fn into_py(self, py: Python<'_>) -> Py<PyConnectionError>[src]
impl<'_> IntoPy<Py<PyConnectionRefusedError>> for &'_ PyConnectionRefusedError[src]
fn into_py(self, py: Python<'_>) -> Py<PyConnectionRefusedError>[src]
impl<'_> IntoPy<Py<PyConnectionResetError>> for &'_ PyConnectionResetError[src]
fn into_py(self, py: Python<'_>) -> Py<PyConnectionResetError>[src]
impl<'_> IntoPy<Py<PyEOFError>> for &'_ PyEOFError[src]
fn into_py(self, py: Python<'_>) -> Py<PyEOFError>[src]
impl<'_> IntoPy<Py<PyEnvironmentError>> for &'_ PyEnvironmentError[src]
fn into_py(self, py: Python<'_>) -> Py<PyEnvironmentError>[src]
impl<'_> IntoPy<Py<PyException>> for &'_ PyException[src]
fn into_py(self, py: Python<'_>) -> Py<PyException>[src]
impl<'_> IntoPy<Py<PyFileExistsError>> for &'_ PyFileExistsError[src]
fn into_py(self, py: Python<'_>) -> Py<PyFileExistsError>[src]
impl<'_> IntoPy<Py<PyFileNotFoundError>> for &'_ PyFileNotFoundError[src]
fn into_py(self, py: Python<'_>) -> Py<PyFileNotFoundError>[src]
impl<'_> IntoPy<Py<PyFloatingPointError>> for &'_ PyFloatingPointError[src]
fn into_py(self, py: Python<'_>) -> Py<PyFloatingPointError>[src]
impl<'_> IntoPy<Py<PyGeneratorExit>> for &'_ PyGeneratorExit[src]
fn into_py(self, py: Python<'_>) -> Py<PyGeneratorExit>[src]
impl<'_> IntoPy<Py<PyIOError>> for &'_ PyIOError[src]
impl<'_> IntoPy<Py<PyImportError>> for &'_ PyImportError[src]
fn into_py(self, py: Python<'_>) -> Py<PyImportError>[src]
impl<'_> IntoPy<Py<PyIndexError>> for &'_ PyIndexError[src]
fn into_py(self, py: Python<'_>) -> Py<PyIndexError>[src]
impl<'_> IntoPy<Py<PyInterruptedError>> for &'_ PyInterruptedError[src]
fn into_py(self, py: Python<'_>) -> Py<PyInterruptedError>[src]
impl<'_> IntoPy<Py<PyIsADirectoryError>> for &'_ PyIsADirectoryError[src]
fn into_py(self, py: Python<'_>) -> Py<PyIsADirectoryError>[src]
impl<'_> IntoPy<Py<PyKeyError>> for &'_ PyKeyError[src]
fn into_py(self, py: Python<'_>) -> Py<PyKeyError>[src]
impl<'_> IntoPy<Py<PyKeyboardInterrupt>> for &'_ PyKeyboardInterrupt[src]
fn into_py(self, py: Python<'_>) -> Py<PyKeyboardInterrupt>[src]
impl<'_> IntoPy<Py<PyLookupError>> for &'_ PyLookupError[src]
fn into_py(self, py: Python<'_>) -> Py<PyLookupError>[src]
impl<'_> IntoPy<Py<PyMemoryError>> for &'_ PyMemoryError[src]
fn into_py(self, py: Python<'_>) -> Py<PyMemoryError>[src]
impl<'_> IntoPy<Py<PyModuleNotFoundError>> for &'_ PyModuleNotFoundError[src]
fn into_py(self, py: Python<'_>) -> Py<PyModuleNotFoundError>[src]
impl<'_> IntoPy<Py<PyNameError>> for &'_ PyNameError[src]
fn into_py(self, py: Python<'_>) -> Py<PyNameError>[src]
impl<'_> IntoPy<Py<PyNotADirectoryError>> for &'_ PyNotADirectoryError[src]
fn into_py(self, py: Python<'_>) -> Py<PyNotADirectoryError>[src]
impl<'_> IntoPy<Py<PyNotImplementedError>> for &'_ PyNotImplementedError[src]
fn into_py(self, py: Python<'_>) -> Py<PyNotImplementedError>[src]
impl<'_> IntoPy<Py<PyOSError>> for &'_ PyOSError[src]
impl<'_> IntoPy<Py<PyOverflowError>> for &'_ PyOverflowError[src]
fn into_py(self, py: Python<'_>) -> Py<PyOverflowError>[src]
impl<'_> IntoPy<Py<PyPermissionError>> for &'_ PyPermissionError[src]
fn into_py(self, py: Python<'_>) -> Py<PyPermissionError>[src]
impl<'_> IntoPy<Py<PyProcessLookupError>> for &'_ PyProcessLookupError[src]
fn into_py(self, py: Python<'_>) -> Py<PyProcessLookupError>[src]
impl<'_> IntoPy<Py<PyRecursionError>> for &'_ PyRecursionError[src]
fn into_py(self, py: Python<'_>) -> Py<PyRecursionError>[src]
impl<'_> IntoPy<Py<PyReferenceError>> for &'_ PyReferenceError[src]
fn into_py(self, py: Python<'_>) -> Py<PyReferenceError>[src]
impl<'_> IntoPy<Py<PyRuntimeError>> for &'_ PyRuntimeError[src]
fn into_py(self, py: Python<'_>) -> Py<PyRuntimeError>[src]
impl<'_> IntoPy<Py<PyStopAsyncIteration>> for &'_ PyStopAsyncIteration[src]
fn into_py(self, py: Python<'_>) -> Py<PyStopAsyncIteration>[src]
impl<'_> IntoPy<Py<PyStopIteration>> for &'_ PyStopIteration[src]
fn into_py(self, py: Python<'_>) -> Py<PyStopIteration>[src]
impl<'_> IntoPy<Py<PySyntaxError>> for &'_ PySyntaxError[src]
fn into_py(self, py: Python<'_>) -> Py<PySyntaxError>[src]
impl<'_> IntoPy<Py<PySystemError>> for &'_ PySystemError[src]
fn into_py(self, py: Python<'_>) -> Py<PySystemError>[src]
impl<'_> IntoPy<Py<PySystemExit>> for &'_ PySystemExit[src]
fn into_py(self, py: Python<'_>) -> Py<PySystemExit>[src]
impl<'_> IntoPy<Py<PyTimeoutError>> for &'_ PyTimeoutError[src]
fn into_py(self, py: Python<'_>) -> Py<PyTimeoutError>[src]
impl<'_> IntoPy<Py<PyTypeError>> for &'_ PyTypeError[src]
fn into_py(self, py: Python<'_>) -> Py<PyTypeError>[src]
impl<'_> IntoPy<Py<PyUnboundLocalError>> for &'_ PyUnboundLocalError[src]
fn into_py(self, py: Python<'_>) -> Py<PyUnboundLocalError>[src]
impl<'_> IntoPy<Py<PyUnicodeDecodeError>> for &'_ PyUnicodeDecodeError[src]
fn into_py(self, py: Python<'_>) -> Py<PyUnicodeDecodeError>[src]
impl<'_> IntoPy<Py<PyUnicodeEncodeError>> for &'_ PyUnicodeEncodeError[src]
fn into_py(self, py: Python<'_>) -> Py<PyUnicodeEncodeError>[src]
impl<'_> IntoPy<Py<PyUnicodeError>> for &'_ PyUnicodeError[src]
fn into_py(self, py: Python<'_>) -> Py<PyUnicodeError>[src]
impl<'_> IntoPy<Py<PyUnicodeTranslateError>> for &'_ PyUnicodeTranslateError[src]
fn into_py(self, py: Python<'_>) -> Py<PyUnicodeTranslateError>[src]
impl<'_> IntoPy<Py<PyValueError>> for &'_ PyValueError[src]
fn into_py(self, py: Python<'_>) -> Py<PyValueError>[src]
impl<'_> IntoPy<Py<PyZeroDivisionError>> for &'_ PyZeroDivisionError[src]
fn into_py(self, py: Python<'_>) -> Py<PyZeroDivisionError>[src]
impl<'_> IntoPy<Py<PanicException>> for &'_ PanicException[src]
fn into_py(self, py: Python<'_>) -> Py<PanicException>[src]
impl<'_> IntoPy<Py<PyModule>> for &'_ PyModule[src]
impl<'_> IntoPy<Py<PyBool>> for &'_ PyBool[src]
impl<'_> IntoPy<Py<PyByteArray>> for &'_ PyByteArray[src]
fn into_py(self, py: Python<'_>) -> Py<PyByteArray>[src]
impl<'_> IntoPy<Py<PyBytes>> for &'_ PyBytes[src]
impl<'_> IntoPy<Py<PyCFunction>> for &'_ PyCFunction[src]
fn into_py(self, py: Python<'_>) -> Py<PyCFunction>[src]
impl<'_> IntoPy<Py<PyComplex>> for &'_ PyComplex[src]
impl<'_> IntoPy<Py<PyDate>> for &'_ PyDate[src]
impl<'_> IntoPy<Py<PyDateTime>> for &'_ PyDateTime[src]
fn into_py(self, py: Python<'_>) -> Py<PyDateTime>[src]
impl<'_> IntoPy<Py<PyDelta>> for &'_ PyDelta[src]
impl<'_> IntoPy<Py<PyDict>> for &'_ PyDict[src]
impl<'_> IntoPy<Py<PyFloat>> for &'_ PyFloat[src]
impl<'_> IntoPy<Py<PyFrozenSet>> for &'_ PyFrozenSet[src]
fn into_py(self, py: Python<'_>) -> Py<PyFrozenSet>[src]
impl<'_> IntoPy<Py<PyFunction>> for &'_ PyFunction[src]
fn into_py(self, py: Python<'_>) -> Py<PyFunction>[src]
impl<'_> IntoPy<Py<PyList>> for &'_ PyList[src]
impl<'_> IntoPy<Py<PyLong>> for &'_ PyLong[src]
impl<'_> IntoPy<Py<PySequence>> for &'_ PySequence[src]
fn into_py(self, py: Python<'_>) -> Py<PySequence>[src]
impl<'_> IntoPy<Py<PySet>> for &'_ PySet[src]
impl<'_> IntoPy<Py<PySlice>> for &'_ PySlice[src]
impl<'_> IntoPy<Py<PyString>> for &'_ PyString[src]
impl<'_> IntoPy<Py<PyTime>> for &'_ PyTime[src]
impl<'_> IntoPy<Py<PyTuple>> for &'_ PyTuple[src]
impl<'_> IntoPy<Py<PyType>> for &'_ PyType[src]
impl<'_> IntoPy<Py<PyTzInfo>> for &'_ PyTzInfo[src]
impl<'a> IntoPy<Py<PyAny>> for &'a PyErr[src]
impl<T> IntoPy<Py<PyAny>> for Py<T>[src]
fn into_py(self, _py: Python<'_>) -> PyObject[src]
Converts a Py instance to PyObject.
Consumes self without calling Py_DECREF().